"""
Provides Klein version information.
"""

# This file is auto-generated! Do not edit!
# Use `python -m incremental.update Klein` to change this file.

from incremental import Version

__version__ = Version("Klein", 24, 8, 0, release_candidate=3)
__all__ = ["__version__"]
